@@ -112,6 +112,7 @@ public:
 
 	virtual KDecoration* createDecoration( KDecorationBridge* b );
 	virtual bool reset( unsigned long changed );
+    virtual bool supports( Ability ability );
 	QValueList< GlowClientGlobals::BorderSize >  borderSizes() const;
 	
 	QString getPixmapName(PixmapType type, bool isActive);
@@ -157,6 +158,7 @@ protected:
 	virtual void paintEvent( QPaintEvent * );
 	virtual void showEvent( QShowEvent * );
 	virtual void mouseDoubleClickEvent( QMouseEvent * );
+	virtual void wheelEvent( QWheelEvent * );
 	virtual void maximizeChange();
 	virtual void activeChange();
 	virtual void iconChange();
